@@ -3,6 +3,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <fcntl.h>
+#include <errno.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 
@@ -56,8 +57,10 @@ init_mime(char *file,char *def)
     int  len,off;
 
     mime_default = strdup(def);
-    if (NULL == (fp = fopen(file,"r")))
+    if (NULL == (fp = fopen(file,"r"))) {
+	fprintf(stderr,"open %s: %s\n",file,strerror(errno));
 	return;
+    }
     while (NULL != fgets(line,127,fp)) {
 	if (line[0] == '#')
 	    continue;
